@@ -7,6 +7,7 @@ from kasten.exceptions import InvalidID
 from mimcvdf import vdf_create, vdf_verify
 
 from onionrblocks.universalrules import check_block_sanity
+from onionrblocks.exceptions import BlockExpired
 
 
 class NotEnoughRounds(Exception):
@@ -69,6 +70,14 @@ class AnonVDFGenerator(generator.KastenBaseGenerator):
                 raise ValueError(
                     "Rounds not specified either in block or as argument")
 
+        test_obj = Kasten(
+            None, packed_bytes, None, auto_check_generator=False)
+        allowed_age_seconds = AnonVDFGenerator.get_ttl_seconds_per_rounds(
+            rounds, len(packed_bytes))
+        if time.time() > test_obj.get_timestamp() + allowed_age_seconds:
+            raise BlockExpired(
+                f"Block rounds only valid through {allowed_age_seconds}")
+
         try:
             hash = int.from_bytes(hash, byteorder="big")
         except TypeError:
@@ -76,12 +85,4 @@ class AnonVDFGenerator(generator.KastenBaseGenerator):
         if not vdf_verify(packed_bytes, hash, rounds):
             raise InvalidID
 
-        test_obj = Kasten(
-            None, packed_bytes, None, auto_check_generator=False)
-        allowed_age_seconds = AnonVDFGenerator.get_ttl_seconds_per_rounds(
-            rounds, len(packed_bytes))
-        if time.time() > test_obj.get_timestamp() + allowed_age_seconds:
-            raise ValueError(
-                f"Block rounds only valid through {allowed_age_seconds}")
-
         return None
\ No newline at end of file
